7160293: [macosx] FileDialog appears on secondary display

Reviewed-by: art, bae
diff --git a/jdk/src/macosx/classes/sun/lwawt/PlatformWindow.java b/jdk/src/macosx/classes/sun/lwawt/PlatformWindow.java
index 378dcab..92608b8 100644
--- a/jdk/src/macosx/classes/sun/lwawt/PlatformWindow.java
+++ b/jdk/src/macosx/classes/sun/lwawt/PlatformWindow.java
@@ -67,9 +67,9 @@
     public void setBounds(int x, int y, int w, int h);
 
     /*
      * Returns the screen number where the window is.
      */
-    public int getScreenImOn();
+    public GraphicsDevice getGraphicsDevice();
 
     /*
      * Returns the location of the window.
@@ -67,9 +67,9 @@
 
     /*
-     * Returns the screen number where the window is.
+     * Returns the graphics device where the window is.
      */